@@ -1,4 +1,4 @@
 pub mod arguments;
 pub mod colored_stream;
 pub mod diagnostic_reporter;
-pub mod render;
+pub mod printer;
