@@ -1,9 +1,11 @@
 pub mod combinations_generator;
-pub mod dynamic_types;
 pub mod environment;
 pub mod name_generator;
 pub mod object;
 pub mod schema;
 pub mod signature;
+pub mod types_table;
 pub mod values;
+
+// Export IndexMap type
 pub use indexmap;
