@@ -18,14 +18,6 @@ pub struct ParserContext {
     pub name_alias_table: HashMap<String, String>,
 
     pub has_select_statement: bool,
-    pub generated_field_count: i32,
     pub is_single_value_query: bool,
     pub has_group_by_statement: bool,
 }
-
-impl ParserContext {
-    pub fn generate_column_name(&mut self) -> String {
-        self.generated_field_count += 1;
-        format!("column_{}", self.generated_field_count)
-    }
-}
