@@ -1,5 +1,8 @@
 pub mod context;
 pub mod diagnostic;
-pub mod parser;
 pub mod tokenizer;
 pub mod type_checker;
+
+pub(crate) mod parse_cast;
+pub(crate) mod parse_type;
+pub mod parser;
