@@ -1,3 +1,5 @@
+use crate::diagnostic::Diagnostic;
+
 #[derive(PartialEq)]
 pub enum TokenKind {
     Do,
@@ -23,6 +25,7 @@ pub enum TokenKind {
     Show,
     RegExp,
 
+    Cast,
     Benchmark,
 
     Join,
@@ -100,6 +103,7 @@ pub enum TokenKind {
     NaN,
 
     Colon,
+    ColonColon,
     ColonEqual,
 
     Plus,
@@ -129,8 +133,6 @@ pub struct Token {
     pub literal: String,
 }
 
-use crate::diagnostic::Diagnostic;
-
 pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
     let mut tokens: Vec<Token> = Vec::new();
 
@@ -611,13 +613,14 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
             continue;
         }
 
-        // Colon or Colon Equal
+        // Colon , ColonColon or Colon Equal
         if char == ':' {
             let location = Location {
                 start: column_start,
                 end: position,
             };
 
+            // :=
             if position + 1 < len && characters[position + 1] == '=' {
                 let token = Token {
                     location,
@@ -630,6 +633,19 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
                 continue;
             }
 
+            // ::
+            if position + 1 < len && characters[position + 1] == ':' {
+                let token = Token {
+                    location,
+                    kind: TokenKind::ColonColon,
+                    literal: "::".to_owned(),
+                };
+
+                tokens.push(token);
+                position += 2;
+                continue;
+            }
+
             let token = Token {
                 location,
                 kind: TokenKind::Colon,
@@ -1169,6 +1185,7 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "show" => TokenKind::Show,
         "regexp" => TokenKind::RegExp,
 
+        "cast" => TokenKind::Cast,
         "benchmark" => TokenKind::Benchmark,
 
         // Select into
